@@ -5,7 +5,7 @@ import OrdinaryDiffEqCore: alg_order, alg_adaptive_order, qsteady_max_default,
                            AbstractController, OrdinaryDiffEqAdaptiveAlgorithm,
                            OrdinaryDiffEqAdamsVarOrderVarStepAlgorithm,
                            alg_cache, OrdinaryDiffEqMutableCache,
-                           OrdinaryDiffEqConstantCache, initialize!, @unpack,
+                           OrdinaryDiffEqConstantCache, initialize!,
                            initialize!, perform_step!, stepsize_controller!,
                            step_accept_controller!, step_reject_controller!,
                            calculate_residuals, calculate_residuals!,
